<!DOCTYPE html>
<html>

<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link rel="shortcut icon" href="/images/fav_icon.png" type="image/x-icon">
    <title>Event Chain</title>
    <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/font-awesome/4.7.0/css/font-awesome.min.css">
    <link href="https://fonts.googleapis.com/css?family=Open+Sans" rel="stylesheet">
    <link rel="stylesheet" href="{{ url_for('static', filename='css/app.css') }}"/>
    <style>
        .columns:nth-child(2) {
            margin-top: -10rem;
        }

    </style>
</head>

<body>
<nav class="navbar is-white" role="navigation" aria-label="main navigation">
    <div class="navbar-brand">
        <a class="navbar-item">
            <img src="{{ url_for('static', filename='images/eventchain.png') }}">
        </a>

        <a role="button" class="navbar-burger burger" aria-label="menu" aria-expanded="false"
           data-target="navbar-basic">
            <span aria-hidden="true"></span>
            <span aria-hidden="true"></span>
            <span aria-hidden="true"></span>
        </a>
    </div>

    <div id="navbar-basic" class="navbar-menu">
        <div class="navbar-start">
            <a class="navbar-item" href="/">
                All Events
            </a>
            <a class="navbar-item" href="/create">
                Create Event
            </a>
            <a class="navbar-item" href="/peek">
                Peek
            </a>


            {% if not session.user %}
                <a class="navbar-item" href="/login">log in</a>
            {% else %}
                <a class="navbar-item" href="/tickets">User: {{ session.user.moniker }}</a>
                <a class="navbar-item" href="/logout">
                    Logout
                </a>
            {% endif %}

        </div>

    </div>
</nav>
<main role="main" class="container">

    {% for message in get_flashed_messages() %}
        <div class="alert alert-info">{{ message }}</div>
    {% endfor %}
    {% block content %}{% endblock %}
</main>
<!-- <script type="text/javascript" src="{{ url_for('static', filename='js/app.js') }}"> -->
