# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: type.proto
import sys

from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

from . import enum_pb2 as enum__pb2
from . import vendor_pb2 as vendor__pb2
_b = sys.version_info[0] < 3 and (
    lambda x: x
) or (lambda x: x.encode('latin1'))
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name='type.proto',
    package='forge_abi',
    syntax='proto3',
    serialized_options=None,
    serialized_pb=_b('\n\ntype.proto\x12\tforge_abi\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\x1a\x0cvendor.proto\x1a\nenum.proto\"\x18\n\x07\x42igUint\x12\r\n\x05value\x18\x01 \x01(\x0c\"\'\n\x07\x42igSint\x12\r\n\x05value\x18\x01 \x01(\x0c\x12\r\n\x05minus\x18\x02 \x01(\x08\"\x9c\x01\n\nWalletType\x12\x1e\n\x02pk\x18\x01 \x01(\x0e\x32\x12.forge_abi.KeyType\x12!\n\x04hash\x18\x02 \x01(\x0e\x32\x13.forge_abi.HashType\x12(\n\x07\x61\x64\x64ress\x18\x03 \x01(\x0e\x32\x17.forge_abi.EncodingType\x12!\n\x04role\x18\x04 \x01(\x0e\x32\x13.forge_abi.RoleType\"Z\n\nWalletInfo\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x15.forge_abi.WalletType\x12\n\n\x02sk\x18\x02 \x01(\x0c\x12\n\n\x02pk\x18\x03 \x01(\x0c\x12\x0f\n\x07\x61\x64\x64ress\x18\x04 \x01(\t\"\xc9\x03\n\tChainInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07network\x18\x02 \x01(\t\x12\x0f\n\x07moniker\x18\x03 \x01(\t\x12\x19\n\x11\x63onsensus_version\x18\x04 \x01(\t\x12\x0e\n\x06synced\x18\x05 \x01(\x08\x12\x10\n\x08\x61pp_hash\x18\x06 \x01(\x0c\x12\x12\n\nblock_hash\x18\x07 \x01(\x0c\x12\x14\n\x0c\x62lock_height\x18\x08 \x01(\x04\x12.\n\nblock_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x61\x64\x64ress\x18\n \x01(\t\x12\x14\n\x0cvoting_power\x18\x0b \x01(\x04\x12\x11\n\ttotal_txs\x18\x0c \x01(\x04\x12\x0f\n\x07version\x18\r \x01(\t\x12\x14\n\x0c\x64\x61ta_version\x18\x0e \x01(\t\x12\x46\n\x12\x66orge_apps_version\x18\x0f \x03(\x0b\x32*.forge_abi.ChainInfo.ForgeAppsVersionEntry\x12\x15\n\rsupported_txs\x18\x10 \x03(\t\x1a\x37\n\x15\x46orgeAppsVersionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf9\x03\n\x08NodeInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07network\x18\x02 \x01(\t\x12\x0f\n\x07moniker\x18\x03 \x01(\t\x12\x19\n\x11\x63onsensus_version\x18\x04 \x01(\t\x12\x0e\n\x06synced\x18\x05 \x01(\x08\x12\x10\n\x08\x61pp_hash\x18\x06 \x01(\x0c\x12\x12\n\nblock_hash\x18\x07 \x01(\x0c\x12\x14\n\x0c\x62lock_height\x18\x08 \x01(\x04\x12.\n\nblock_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x61\x64\x64ress\x18\n \x01(\t\x12\x14\n\x0cvoting_power\x18\x0b \x01(\x04\x12\x11\n\ttotal_txs\x18\x0c \x01(\x04\x12\x0f\n\x07version\x18\r \x01(\t\x12\x14\n\x0c\x64\x61ta_version\x18\x0e \x01(\t\x12\x45\n\x12\x66orge_apps_version\x18\x0f \x03(\x0b\x32).forge_abi.NodeInfo.ForgeAppsVersionEntry\x12\x15\n\rsupported_txs\x18\x10 \x03(\t\x12\n\n\x02ip\x18\x11 \x01(\t\x12$\n\x08geo_info\x18\x12 \x01(\x0b\x32\x12.forge_abi.GeoInfo\x1a\x37\n\x15\x46orgeAppsVersionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\tValidator\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\r\n\x05power\x18\x02 \x01(\x04\"\xd8\x01\n\x0f\x43onsensusParams\x12\x11\n\tmax_bytes\x18\x01 \x01(\x04\x12\x0f\n\x07max_gas\x18\x02 \x01(\x12\x12\x16\n\x0emax_validators\x18\x03 \x01(\r\x12\x16\n\x0emax_candidates\x18\x04 \x01(\r\x12\x15\n\rpub_key_types\x18\x05 \x03(\t\x12(\n\nvalidators\x18\x06 \x03(\x0b\x32\x14.forge_abi.Validator\x12\x19\n\x11validator_changed\x18\x07 \x01(\x08\x12\x15\n\rparam_changed\x18\x08 \x01(\x08\"q\n\x0bUpgradeTask\x12$\n\x04type\x18\x01 \x01(\x0e\x32\x16.forge_abi.UpgradeType\x12\x11\n\tdata_hash\x18\x02 \x01(\t\x12)\n\x07\x61\x63tions\x18\x04 \x03(\x0e\x32\x18.forge_abi.UpgradeAction\"4\n\x0cUpgradeTasks\x12$\n\x04item\x18\x01 \x03(\x0b\x32\x16.forge_abi.UpgradeTask\"\xee\x01\n\x0b\x41\x62\x63iContext\x12\x0f\n\x07tx_hash\x18\x01 \x01(\t\x12\x14\n\x0c\x62lock_height\x18\x02 \x01(\x04\x12.\n\nblock_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\ttotal_txs\x18\x04 \x01(\x04\x12.\n\rtx_statistics\x18\x05 \x01(\x0b\x32\x17.forge_abi.TxStatistics\x12\x10\n\x08tx_index\x18\x06 \x01(\r\x12\x33\n\x0flast_block_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"Q\n\x08Multisig\x12\x0e\n\x06signer\x18\x01 \x01(\t\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x12\"\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any\"\x9b\x01\n\x0bTransaction\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\r\n\x05nonce\x18\x02 \x01(\x04\x12\x11\n\tsignature\x18\x03 \x01(\x0c\x12\x10\n\x08\x63hain_id\x18\x04 \x01(\t\x12\'\n\nsignatures\x18\x05 \x03(\x0b\x32\x13.forge_abi.Multisig\x12!\n\x03itx\x18\x07 \x01(\x0b\x32\x14.google.protobuf.Any\"\xaa\x01\n\x0fTransactionInfo\x12\"\n\x02tx\x18\x01 \x01(\x0b\x32\x16.forge_abi.Transaction\x12\x0e\n\x06height\x18\x02 \x01(\x04\x12\r\n\x05index\x18\x03 \x01(\r\x12\x0c\n\x04hash\x18\x04 \x01(\t\x12!\n\x04tags\x18\x05 \x03(\x0b\x32\x13.abci_vendor.KVPair\x12#\n\x04\x63ode\x18\x06 \x01(\x0e\x32\x15.forge_abi.StatusCode\"\xb6\x01\n\tBlockInfo\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x0f\n\x07num_txs\x18\x02 \x01(\r\x12(\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08\x61pp_hash\x18\x04 \x01(\t\x12\x10\n\x08proposer\x18\x05 \x01(\t\x12\'\n\x03txs\x18\x06 \x03(\x0b\x32\x1a.forge_abi.TransactionInfo\x12\x11\n\ttotal_txs\x18\x07 \x01(\x04\"=\n\x08TxStatus\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12\x0c\n\x04hash\x18\x02 \x01(\t\"c\n\rCircularQueue\x12\r\n\x05items\x18\x01 \x03(\x0c\x12\x10\n\x08type_url\x18\x02 \x01(\t\x12\x11\n\tmax_items\x18\x03 \x01(\r\x12\x10\n\x08\x63ircular\x18\x04 \x01(\x08\x12\x0c\n\x04\x66ifo\x18\x05 \x01(\x08\"\xa2\x01\n\x0cStateContext\x12\x12\n\ngenesis_tx\x18\x01 \x01(\t\x12\x16\n\x0erenaissance_tx\x18\x02 \x01(\t\x12\x30\n\x0cgenesis_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10renaissance_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x82\x02\n\x0cStakeContext\x12(\n\x0ctotal_stakes\x18\x01 \x01(\x0b\x32\x12.forge_abi.BigUint\x12*\n\x0etotal_unstakes\x18\x02 \x01(\x0b\x32\x12.forge_abi.BigUint\x12\x31\n\x15total_received_stakes\x18\x03 \x01(\x0b\x32\x12.forge_abi.BigUint\x12/\n\rrecent_stakes\x18\x04 \x01(\x0b\x32\x18.forge_abi.CircularQueue\x12\x38\n\x16recent_received_stakes\x18\x0f \x01(\x0b\x32\x18.forge_abi.CircularQueue\"\x8e\x01\n\x0cStakeSummary\x12(\n\x0ctotal_stakes\x18\x01 \x01(\x0b\x32\x12.forge_abi.BigUint\x12*\n\x0etotal_unstakes\x18\x02 \x01(\x0b\x32\x12.forge_abi.BigUint\x12(\n\x07\x63ontext\x18\x03 \x01(\x0b\x32\x17.forge_abi.StateContext\"D\n\x0eUnconfirmedTxs\x12\r\n\x05n_txs\x18\x01 \x01(\r\x12#\n\x03txs\x18\x02 \x03(\x0b\x32\x16.forge_abi.Transaction\"d\n\x07NetInfo\x12\x11\n\tlistening\x18\x01 \x01(\x08\x12\x11\n\tlisteners\x18\x02 \x03(\t\x12\x0f\n\x07n_peers\x18\x03 \x01(\r\x12\"\n\x05peers\x18\x04 \x03(\x0b\x32\x13.forge_abi.PeerInfo\"M\n\x07GeoInfo\x12\x0c\n\x04\x63ity\x18\x01 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x02 \x01(\t\x12\x10\n\x08latitude\x18\x03 \x01(\x02\x12\x11\n\tlongitude\x18\x04 \x01(\x02\"\x85\x01\n\x08PeerInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07network\x18\x02 \x01(\t\x12\x19\n\x11\x63onsensus_version\x18\x03 \x01(\t\x12\x0f\n\x07moniker\x18\x04 \x01(\t\x12\n\n\x02ip\x18\x05 \x01(\t\x12$\n\x08geo_info\x18\x06 \x01(\x0b\x32\x12.forge_abi.GeoInfo\"T\n\x0eValidatorsInfo\x12\x14\n\x0c\x62lock_height\x18\x01 \x01(\x04\x12,\n\nvalidators\x18\x02 \x03(\x0b\x32\x18.forge_abi.ValidatorInfo\"\x85\x01\n\rValidatorInfo\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12$\n\x07pub_key\x18\x02 \x01(\x0b\x32\x13.abci_vendor.PubKey\x12\x14\n\x0cvoting_power\x18\x03 \x01(\x04\x12\x19\n\x11proposer_priority\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\"\xad\x01\n\x0bGenesisInfo\x12\x14\n\x0cgenesis_time\x18\x01 \x01(\t\x12\x10\n\x08\x63hain_id\x18\x02 \x01(\t\x12\x36\n\x10\x63onsensus_params\x18\x03 \x01(\x0b\x32\x1c.abci_vendor.ConsensusParams\x12,\n\nvalidators\x18\x04 \x03(\x0b\x32\x18.forge_abi.ValidatorInfo\x12\x10\n\x08\x61pp_hash\x18\x05 \x01(\t\"\xb4\x03\n\x0f\x46orgeStatistics\x12\x12\n\nnum_blocks\x18\x01 \x03(\x04\x12\x0f\n\x07num_txs\x18\x02 \x03(\x04\x12&\n\nnum_stakes\x18\x03 \x03(\x0b\x32\x12.forge_abi.BigUint\x12\x16\n\x0enum_validators\x18\x04 \x03(\r\x12\x1f\n\x17num_account_migrate_txs\x18\x05 \x03(\x04\x12\x1c\n\x14num_create_asset_txs\x18\x06 \x03(\x04\x12!\n\x19num_consensus_upgrade_txs\x18\x07 \x03(\r\x12\x17\n\x0fnum_declare_txs\x18\x08 \x03(\x04\x12\x1c\n\x14num_declare_file_txs\x18\t \x03(\x04\x12\x18\n\x10num_exchange_txs\x18\n \x03(\x04\x12\x15\n\rnum_stake_txs\x18\x0b \x03(\x04\x12\x1b\n\x13num_sys_upgrade_txs\x18\x0c \x03(\r\x12\x18\n\x10num_transfer_txs\x18\r \x03(\x04\x12\x1c\n\x14num_update_asset_txs\x18\x0e \x03(\x04\x12\x1d\n\x15num_consume_asset_txs\x18\x0f \x03(\x04\"\xcc\x02\n\x0cTxStatistics\x12\x1f\n\x17num_account_migrate_txs\x18\x01 \x01(\x04\x12\x1c\n\x14num_create_asset_txs\x18\x02 \x01(\x04\x12!\n\x19num_consensus_upgrade_txs\x18\x03 \x01(\r\x12\x17\n\x0fnum_declare_txs\x18\x04 \x01(\x04\x12\x1c\n\x14num_declare_file_txs\x18\x05 \x01(\x04\x12\x18\n\x10num_exchange_txs\x18\x06 \x01(\x04\x12\x15\n\rnum_stake_txs\x18\x07 \x01(\x04\x12\x1b\n\x13num_sys_upgrade_txs\x18\x08 \x01(\r\x12\x18\n\x10num_transfer_txs\x18\t \x01(\x04\x12\x1c\n\x14num_update_asset_txs\x18\n \x01(\x04\x12\x1d\n\x15num_consume_asset_txs\x18\x0b \x01(\x04\x62\x06proto3'),
    dependencies=[
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_any__pb2.DESCRIPTOR, vendor__pb2.DESCRIPTOR, enum__pb2.DESCRIPTOR, ],
)


_BIGUINT = _descriptor.Descriptor(
    name='BigUint',
    full_name='forge_abi.BigUint',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='value', full_name='forge_abi.BigUint.value', index=0,
            number=1, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=111,
    serialized_end=135,
)


_BIGSINT = _descriptor.Descriptor(
    name='BigSint',
    full_name='forge_abi.BigSint',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='value', full_name='forge_abi.BigSint.value', index=0,
            number=1, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='minus', full_name='forge_abi.BigSint.minus', index=1,
            number=2, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=137,
    serialized_end=176,
)


_WALLETTYPE = _descriptor.Descriptor(
    name='WalletType',
    full_name='forge_abi.WalletType',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='pk', full_name='forge_abi.WalletType.pk', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='hash', full_name='forge_abi.WalletType.hash', index=1,
            number=2, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='address', full_name='forge_abi.WalletType.address', index=2,
            number=3, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='role', full_name='forge_abi.WalletType.role', index=3,
            number=4, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=179,
    serialized_end=335,
)


_WALLETINFO = _descriptor.Descriptor(
    name='WalletInfo',
    full_name='forge_abi.WalletInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='type', full_name='forge_abi.WalletInfo.type', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='sk', full_name='forge_abi.WalletInfo.sk', index=1,
            number=2, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='pk', full_name='forge_abi.WalletInfo.pk', index=2,
            number=3, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='address', full_name='forge_abi.WalletInfo.address', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=337,
    serialized_end=427,
)


_CHAININFO_FORGEAPPSVERSIONENTRY = _descriptor.Descriptor(
    name='ForgeAppsVersionEntry',
    full_name='forge_abi.ChainInfo.ForgeAppsVersionEntry',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='key', full_name='forge_abi.ChainInfo.ForgeAppsVersionEntry.key', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='value', full_name='forge_abi.ChainInfo.ForgeAppsVersionEntry.value', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=_b('8\001'),
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=832,
    serialized_end=887,
)

_CHAININFO = _descriptor.Descriptor(
    name='ChainInfo',
    full_name='forge_abi.ChainInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='id', full_name='forge_abi.ChainInfo.id', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='network', full_name='forge_abi.ChainInfo.network', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='moniker', full_name='forge_abi.ChainInfo.moniker', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='consensus_version', full_name='forge_abi.ChainInfo.consensus_version', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='synced', full_name='forge_abi.ChainInfo.synced', index=4,
            number=5, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='app_hash', full_name='forge_abi.ChainInfo.app_hash', index=5,
            number=6, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='block_hash', full_name='forge_abi.ChainInfo.block_hash', index=6,
            number=7, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='block_height', full_name='forge_abi.ChainInfo.block_height', index=7,
            number=8, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='block_time', full_name='forge_abi.ChainInfo.block_time', index=8,
            number=9, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='address', full_name='forge_abi.ChainInfo.address', index=9,
            number=10, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='voting_power', full_name='forge_abi.ChainInfo.voting_power', index=10,
            number=11, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='total_txs', full_name='forge_abi.ChainInfo.total_txs', index=11,
            number=12, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='version', full_name='forge_abi.ChainInfo.version', index=12,
            number=13, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='data_version', full_name='forge_abi.ChainInfo.data_version', index=13,
            number=14, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='forge_apps_version', full_name='forge_abi.ChainInfo.forge_apps_version', index=14,
            number=15, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='supported_txs', full_name='forge_abi.ChainInfo.supported_txs', index=15,
            number=16, type=9, cpp_type=9, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[_CHAININFO_FORGEAPPSVERSIONENTRY, ],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=430,
    serialized_end=887,
)


_NODEINFO_FORGEAPPSVERSIONENTRY = _descriptor.Descriptor(
    name='ForgeAppsVersionEntry',
    full_name='forge_abi.NodeInfo.ForgeAppsVersionEntry',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='key', full_name='forge_abi.NodeInfo.ForgeAppsVersionEntry.key', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='value', full_name='forge_abi.NodeInfo.ForgeAppsVersionEntry.value', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=_b('8\001'),
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=832,
    serialized_end=887,
)

_NODEINFO = _descriptor.Descriptor(
    name='NodeInfo',
    full_name='forge_abi.NodeInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='id', full_name='forge_abi.NodeInfo.id', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='network', full_name='forge_abi.NodeInfo.network', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='moniker', full_name='forge_abi.NodeInfo.moniker', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='consensus_version', full_name='forge_abi.NodeInfo.consensus_version', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='synced', full_name='forge_abi.NodeInfo.synced', index=4,
            number=5, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='app_hash', full_name='forge_abi.NodeInfo.app_hash', index=5,
            number=6, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='block_hash', full_name='forge_abi.NodeInfo.block_hash', index=6,
            number=7, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='block_height', full_name='forge_abi.NodeInfo.block_height', index=7,
            number=8, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='block_time', full_name='forge_abi.NodeInfo.block_time', index=8,
            number=9, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='address', full_name='forge_abi.NodeInfo.address', index=9,
            number=10, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='voting_power', full_name='forge_abi.NodeInfo.voting_power', index=10,
            number=11, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='total_txs', full_name='forge_abi.NodeInfo.total_txs', index=11,
            number=12, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='version', full_name='forge_abi.NodeInfo.version', index=12,
            number=13, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='data_version', full_name='forge_abi.NodeInfo.data_version', index=13,
            number=14, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='forge_apps_version', full_name='forge_abi.NodeInfo.forge_apps_version', index=14,
            number=15, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='supported_txs', full_name='forge_abi.NodeInfo.supported_txs', index=15,
            number=16, type=9, cpp_type=9, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='ip', full_name='forge_abi.NodeInfo.ip', index=16,
            number=17, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='geo_info', full_name='forge_abi.NodeInfo.geo_info', index=17,
            number=18, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[_NODEINFO_FORGEAPPSVERSIONENTRY, ],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=890,
    serialized_end=1395,
)


_VALIDATOR = _descriptor.Descriptor(
    name='Validator',
    full_name='forge_abi.Validator',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='address', full_name='forge_abi.Validator.address', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='power', full_name='forge_abi.Validator.power', index=1,
            number=2, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1397,
    serialized_end=1440,
)


_CONSENSUSPARAMS = _descriptor.Descriptor(
    name='ConsensusParams',
    full_name='forge_abi.ConsensusParams',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='max_bytes', full_name='forge_abi.ConsensusParams.max_bytes', index=0,
            number=1, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='max_gas', full_name='forge_abi.ConsensusParams.max_gas', index=1,
            number=2, type=18, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='max_validators', full_name='forge_abi.ConsensusParams.max_validators', index=2,
            number=3, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='max_candidates', full_name='forge_abi.ConsensusParams.max_candidates', index=3,
            number=4, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='pub_key_types', full_name='forge_abi.ConsensusParams.pub_key_types', index=4,
            number=5, type=9, cpp_type=9, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='validators', full_name='forge_abi.ConsensusParams.validators', index=5,
            number=6, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='validator_changed', full_name='forge_abi.ConsensusParams.validator_changed', index=6,
            number=7, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='param_changed', full_name='forge_abi.ConsensusParams.param_changed', index=7,
            number=8, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1443,
    serialized_end=1659,
)


_UPGRADETASK = _descriptor.Descriptor(
    name='UpgradeTask',
    full_name='forge_abi.UpgradeTask',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='type', full_name='forge_abi.UpgradeTask.type', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='data_hash', full_name='forge_abi.UpgradeTask.data_hash', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='actions', full_name='forge_abi.UpgradeTask.actions', index=2,
            number=4, type=14, cpp_type=8, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1661,
    serialized_end=1774,
)


_UPGRADETASKS = _descriptor.Descriptor(
    name='UpgradeTasks',
    full_name='forge_abi.UpgradeTasks',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='item', full_name='forge_abi.UpgradeTasks.item', index=0,
            number=1, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1776,
    serialized_end=1828,
)


_ABCICONTEXT = _descriptor.Descriptor(
    name='AbciContext',
    full_name='forge_abi.AbciContext',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='tx_hash', full_name='forge_abi.AbciContext.tx_hash', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='block_height', full_name='forge_abi.AbciContext.block_height', index=1,
            number=2, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='block_time', full_name='forge_abi.AbciContext.block_time', index=2,
            number=3, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='total_txs', full_name='forge_abi.AbciContext.total_txs', index=3,
            number=4, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='tx_statistics', full_name='forge_abi.AbciContext.tx_statistics', index=4,
            number=5, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='tx_index', full_name='forge_abi.AbciContext.tx_index', index=5,
            number=6, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='last_block_time', full_name='forge_abi.AbciContext.last_block_time', index=6,
            number=7, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1831,
    serialized_end=2069,
)


_MULTISIG = _descriptor.Descriptor(
    name='Multisig',
    full_name='forge_abi.Multisig',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='signer', full_name='forge_abi.Multisig.signer', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='signature', full_name='forge_abi.Multisig.signature', index=1,
            number=2, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='data', full_name='forge_abi.Multisig.data', index=2,
            number=3, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2071,
    serialized_end=2152,
)


_TRANSACTION = _descriptor.Descriptor(
    name='Transaction',
    full_name='forge_abi.Transaction',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='from', full_name='forge_abi.Transaction.from', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='nonce', full_name='forge_abi.Transaction.nonce', index=1,
            number=2, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='signature', full_name='forge_abi.Transaction.signature', index=2,
            number=3, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='chain_id', full_name='forge_abi.Transaction.chain_id', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='signatures', full_name='forge_abi.Transaction.signatures', index=4,
            number=5, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='itx', full_name='forge_abi.Transaction.itx', index=5,
            number=7, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2155,
    serialized_end=2310,
)


_TRANSACTIONINFO = _descriptor.Descriptor(
    name='TransactionInfo',
    full_name='forge_abi.TransactionInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='tx', full_name='forge_abi.TransactionInfo.tx', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='height', full_name='forge_abi.TransactionInfo.height', index=1,
            number=2, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='index', full_name='forge_abi.TransactionInfo.index', index=2,
            number=3, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='hash', full_name='forge_abi.TransactionInfo.hash', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='tags', full_name='forge_abi.TransactionInfo.tags', index=4,
            number=5, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.TransactionInfo.code', index=5,
            number=6, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2313,
    serialized_end=2483,
)


_BLOCKINFO = _descriptor.Descriptor(
    name='BlockInfo',
    full_name='forge_abi.BlockInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='height', full_name='forge_abi.BlockInfo.height', index=0,
            number=1, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_txs', full_name='forge_abi.BlockInfo.num_txs', index=1,
            number=2, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='time', full_name='forge_abi.BlockInfo.time', index=2,
            number=3, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='app_hash', full_name='forge_abi.BlockInfo.app_hash', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='proposer', full_name='forge_abi.BlockInfo.proposer', index=4,
            number=5, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='txs', full_name='forge_abi.BlockInfo.txs', index=5,
            number=6, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='total_txs', full_name='forge_abi.BlockInfo.total_txs', index=6,
            number=7, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2486,
    serialized_end=2668,
)


_TXSTATUS = _descriptor.Descriptor(
    name='TxStatus',
    full_name='forge_abi.TxStatus',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.TxStatus.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='hash', full_name='forge_abi.TxStatus.hash', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2670,
    serialized_end=2731,
)


_CIRCULARQUEUE = _descriptor.Descriptor(
    name='CircularQueue',
    full_name='forge_abi.CircularQueue',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='items', full_name='forge_abi.CircularQueue.items', index=0,
            number=1, type=12, cpp_type=9, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='type_url', full_name='forge_abi.CircularQueue.type_url', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='max_items', full_name='forge_abi.CircularQueue.max_items', index=2,
            number=3, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='circular', full_name='forge_abi.CircularQueue.circular', index=3,
            number=4, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='fifo', full_name='forge_abi.CircularQueue.fifo', index=4,
            number=5, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2733,
    serialized_end=2832,
)


_STATECONTEXT = _descriptor.Descriptor(
    name='StateContext',
    full_name='forge_abi.StateContext',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='genesis_tx', full_name='forge_abi.StateContext.genesis_tx', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='renaissance_tx', full_name='forge_abi.StateContext.renaissance_tx', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='genesis_time', full_name='forge_abi.StateContext.genesis_time', index=2,
            number=3, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='renaissance_time', full_name='forge_abi.StateContext.renaissance_time', index=3,
            number=4, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2835,
    serialized_end=2997,
)


_STAKECONTEXT = _descriptor.Descriptor(
    name='StakeContext',
    full_name='forge_abi.StakeContext',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='total_stakes', full_name='forge_abi.StakeContext.total_stakes', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='total_unstakes', full_name='forge_abi.StakeContext.total_unstakes', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='total_received_stakes', full_name='forge_abi.StakeContext.total_received_stakes', index=2,
            number=3, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='recent_stakes', full_name='forge_abi.StakeContext.recent_stakes', index=3,
            number=4, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='recent_received_stakes', full_name='forge_abi.StakeContext.recent_received_stakes', index=4,
            number=15, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3000,
    serialized_end=3258,
)


_STAKESUMMARY = _descriptor.Descriptor(
    name='StakeSummary',
    full_name='forge_abi.StakeSummary',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='total_stakes', full_name='forge_abi.StakeSummary.total_stakes', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='total_unstakes', full_name='forge_abi.StakeSummary.total_unstakes', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='context', full_name='forge_abi.StakeSummary.context', index=2,
            number=3, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3261,
    serialized_end=3403,
)


_UNCONFIRMEDTXS = _descriptor.Descriptor(
    name='UnconfirmedTxs',
    full_name='forge_abi.UnconfirmedTxs',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='n_txs', full_name='forge_abi.UnconfirmedTxs.n_txs', index=0,
            number=1, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='txs', full_name='forge_abi.UnconfirmedTxs.txs', index=1,
            number=2, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3405,
    serialized_end=3473,
)


_NETINFO = _descriptor.Descriptor(
    name='NetInfo',
    full_name='forge_abi.NetInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='listening', full_name='forge_abi.NetInfo.listening', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='listeners', full_name='forge_abi.NetInfo.listeners', index=1,
            number=2, type=9, cpp_type=9, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='n_peers', full_name='forge_abi.NetInfo.n_peers', index=2,
            number=3, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='peers', full_name='forge_abi.NetInfo.peers', index=3,
            number=4, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3475,
    serialized_end=3575,
)


_GEOINFO = _descriptor.Descriptor(
    name='GeoInfo',
    full_name='forge_abi.GeoInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='city', full_name='forge_abi.GeoInfo.city', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='country', full_name='forge_abi.GeoInfo.country', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='latitude', full_name='forge_abi.GeoInfo.latitude', index=2,
            number=3, type=2, cpp_type=6, label=1,
            has_default_value=False, default_value=float(0),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='longitude', full_name='forge_abi.GeoInfo.longitude', index=3,
            number=4, type=2, cpp_type=6, label=1,
            has_default_value=False, default_value=float(0),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3577,
    serialized_end=3654,
)


_PEERINFO = _descriptor.Descriptor(
    name='PeerInfo',
    full_name='forge_abi.PeerInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='id', full_name='forge_abi.PeerInfo.id', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='network', full_name='forge_abi.PeerInfo.network', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='consensus_version', full_name='forge_abi.PeerInfo.consensus_version', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='moniker', full_name='forge_abi.PeerInfo.moniker', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='ip', full_name='forge_abi.PeerInfo.ip', index=4,
            number=5, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='geo_info', full_name='forge_abi.PeerInfo.geo_info', index=5,
            number=6, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3657,
    serialized_end=3790,
)


_VALIDATORSINFO = _descriptor.Descriptor(
    name='ValidatorsInfo',
    full_name='forge_abi.ValidatorsInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='block_height', full_name='forge_abi.ValidatorsInfo.block_height', index=0,
            number=1, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='validators', full_name='forge_abi.ValidatorsInfo.validators', index=1,
            number=2, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3792,
    serialized_end=3876,
)


_VALIDATORINFO = _descriptor.Descriptor(
    name='ValidatorInfo',
    full_name='forge_abi.ValidatorInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='address', full_name='forge_abi.ValidatorInfo.address', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='pub_key', full_name='forge_abi.ValidatorInfo.pub_key', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='voting_power', full_name='forge_abi.ValidatorInfo.voting_power', index=2,
            number=3, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='proposer_priority', full_name='forge_abi.ValidatorInfo.proposer_priority', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='name', full_name='forge_abi.ValidatorInfo.name', index=4,
            number=5, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3879,
    serialized_end=4012,
)


_GENESISINFO = _descriptor.Descriptor(
    name='GenesisInfo',
    full_name='forge_abi.GenesisInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='genesis_time', full_name='forge_abi.GenesisInfo.genesis_time', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='chain_id', full_name='forge_abi.GenesisInfo.chain_id', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='consensus_params', full_name='forge_abi.GenesisInfo.consensus_params', index=2,
            number=3, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='validators', full_name='forge_abi.GenesisInfo.validators', index=3,
            number=4, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='app_hash', full_name='forge_abi.GenesisInfo.app_hash', index=4,
            number=5, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=4015,
    serialized_end=4188,
)


_FORGESTATISTICS = _descriptor.Descriptor(
    name='ForgeStatistics',
    full_name='forge_abi.ForgeStatistics',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='num_blocks', full_name='forge_abi.ForgeStatistics.num_blocks', index=0,
            number=1, type=4, cpp_type=4, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_txs', full_name='forge_abi.ForgeStatistics.num_txs', index=1,
            number=2, type=4, cpp_type=4, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_stakes', full_name='forge_abi.ForgeStatistics.num_stakes', index=2,
            number=3, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_validators', full_name='forge_abi.ForgeStatistics.num_validators', index=3,
            number=4, type=13, cpp_type=3, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_account_migrate_txs', full_name='forge_abi.ForgeStatistics.num_account_migrate_txs', index=4,
            number=5, type=4, cpp_type=4, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_create_asset_txs', full_name='forge_abi.ForgeStatistics.num_create_asset_txs', index=5,
            number=6, type=4, cpp_type=4, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_consensus_upgrade_txs', full_name='forge_abi.ForgeStatistics.num_consensus_upgrade_txs', index=6,
            number=7, type=13, cpp_type=3, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_declare_txs', full_name='forge_abi.ForgeStatistics.num_declare_txs', index=7,
            number=8, type=4, cpp_type=4, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_declare_file_txs', full_name='forge_abi.ForgeStatistics.num_declare_file_txs', index=8,
            number=9, type=4, cpp_type=4, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_exchange_txs', full_name='forge_abi.ForgeStatistics.num_exchange_txs', index=9,
            number=10, type=4, cpp_type=4, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_stake_txs', full_name='forge_abi.ForgeStatistics.num_stake_txs', index=10,
            number=11, type=4, cpp_type=4, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_sys_upgrade_txs', full_name='forge_abi.ForgeStatistics.num_sys_upgrade_txs', index=11,
            number=12, type=13, cpp_type=3, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_transfer_txs', full_name='forge_abi.ForgeStatistics.num_transfer_txs', index=12,
            number=13, type=4, cpp_type=4, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_update_asset_txs', full_name='forge_abi.ForgeStatistics.num_update_asset_txs', index=13,
            number=14, type=4, cpp_type=4, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_consume_asset_txs', full_name='forge_abi.ForgeStatistics.num_consume_asset_txs', index=14,
            number=15, type=4, cpp_type=4, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=4191,
    serialized_end=4627,
)


_TXSTATISTICS = _descriptor.Descriptor(
    name='TxStatistics',
    full_name='forge_abi.TxStatistics',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='num_account_migrate_txs', full_name='forge_abi.TxStatistics.num_account_migrate_txs', index=0,
            number=1, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_create_asset_txs', full_name='forge_abi.TxStatistics.num_create_asset_txs', index=1,
            number=2, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_consensus_upgrade_txs', full_name='forge_abi.TxStatistics.num_consensus_upgrade_txs', index=2,
            number=3, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_declare_txs', full_name='forge_abi.TxStatistics.num_declare_txs', index=3,
            number=4, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_declare_file_txs', full_name='forge_abi.TxStatistics.num_declare_file_txs', index=4,
            number=5, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_exchange_txs', full_name='forge_abi.TxStatistics.num_exchange_txs', index=5,
            number=6, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_stake_txs', full_name='forge_abi.TxStatistics.num_stake_txs', index=6,
            number=7, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_sys_upgrade_txs', full_name='forge_abi.TxStatistics.num_sys_upgrade_txs', index=7,
            number=8, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_transfer_txs', full_name='forge_abi.TxStatistics.num_transfer_txs', index=8,
            number=9, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_update_asset_txs', full_name='forge_abi.TxStatistics.num_update_asset_txs', index=9,
            number=10, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='num_consume_asset_txs', full_name='forge_abi.TxStatistics.num_consume_asset_txs', index=10,
            number=11, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=4630,
    serialized_end=4962,
)

_WALLETTYPE.fields_by_name['pk'].enum_type = enum__pb2._KEYTYPE
_WALLETTYPE.fields_by_name['hash'].enum_type = enum__pb2._HASHTYPE
_WALLETTYPE.fields_by_name['address'].enum_type = enum__pb2._ENCODINGTYPE
_WALLETTYPE.fields_by_name['role'].enum_type = enum__pb2._ROLETYPE
_WALLETINFO.fields_by_name['type'].message_type = _WALLETTYPE
_CHAININFO_FORGEAPPSVERSIONENTRY.containing_type = _CHAININFO
_CHAININFO.fields_by_name['block_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CHAININFO.fields_by_name['forge_apps_version'].message_type = _CHAININFO_FORGEAPPSVERSIONENTRY
_NODEINFO_FORGEAPPSVERSIONENTRY.containing_type = _NODEINFO
_NODEINFO.fields_by_name['block_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_NODEINFO.fields_by_name['forge_apps_version'].message_type = _NODEINFO_FORGEAPPSVERSIONENTRY
_NODEINFO.fields_by_name['geo_info'].message_type = _GEOINFO
_CONSENSUSPARAMS.fields_by_name['validators'].message_type = _VALIDATOR
_UPGRADETASK.fields_by_name['type'].enum_type = enum__pb2._UPGRADETYPE
_UPGRADETASK.fields_by_name['actions'].enum_type = enum__pb2._UPGRADEACTION
_UPGRADETASKS.fields_by_name['item'].message_type = _UPGRADETASK
_ABCICONTEXT.fields_by_name['block_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ABCICONTEXT.fields_by_name['tx_statistics'].message_type = _TXSTATISTICS
_ABCICONTEXT.fields_by_name['last_block_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MULTISIG.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_TRANSACTION.fields_by_name['signatures'].message_type = _MULTISIG
_TRANSACTION.fields_by_name['itx'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_TRANSACTIONINFO.fields_by_name['tx'].message_type = _TRANSACTION
_TRANSACTIONINFO.fields_by_name['tags'].message_type = vendor__pb2._KVPAIR
_TRANSACTIONINFO.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_BLOCKINFO.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BLOCKINFO.fields_by_name['txs'].message_type = _TRANSACTIONINFO
_TXSTATUS.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_STATECONTEXT.fields_by_name['genesis_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STATECONTEXT.fields_by_name['renaissance_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STAKECONTEXT.fields_by_name['total_stakes'].message_type = _BIGUINT
_STAKECONTEXT.fields_by_name['total_unstakes'].message_type = _BIGUINT
_STAKECONTEXT.fields_by_name['total_received_stakes'].message_type = _BIGUINT
_STAKECONTEXT.fields_by_name['recent_stakes'].message_type = _CIRCULARQUEUE
_STAKECONTEXT.fields_by_name['recent_received_stakes'].message_type = _CIRCULARQUEUE
_STAKESUMMARY.fields_by_name['total_stakes'].message_type = _BIGUINT
_STAKESUMMARY.fields_by_name['total_unstakes'].message_type = _BIGUINT
_STAKESUMMARY.fields_by_name['context'].message_type = _STATECONTEXT
_UNCONFIRMEDTXS.fields_by_name['txs'].message_type = _TRANSACTION
_NETINFO.fields_by_name['peers'].message_type = _PEERINFO
_PEERINFO.fields_by_name['geo_info'].message_type = _GEOINFO
_VALIDATORSINFO.fields_by_name['validators'].message_type = _VALIDATORINFO
_VALIDATORINFO.fields_by_name['pub_key'].message_type = vendor__pb2._PUBKEY
_GENESISINFO.fields_by_name['consensus_params'].message_type = vendor__pb2._CONSENSUSPARAMS
_GENESISINFO.fields_by_name['validators'].message_type = _VALIDATORINFO
_FORGESTATISTICS.fields_by_name['num_stakes'].message_type = _BIGUINT
DESCRIPTOR.message_types_by_name['BigUint'] = _BIGUINT
DESCRIPTOR.message_types_by_name['BigSint'] = _BIGSINT
DESCRIPTOR.message_types_by_name['WalletType'] = _WALLETTYPE
DESCRIPTOR.message_types_by_name['WalletInfo'] = _WALLETINFO
DESCRIPTOR.message_types_by_name['ChainInfo'] = _CHAININFO
DESCRIPTOR.message_types_by_name['NodeInfo'] = _NODEINFO
DESCRIPTOR.message_types_by_name['Validator'] = _VALIDATOR
DESCRIPTOR.message_types_by_name['ConsensusParams'] = _CONSENSUSPARAMS
DESCRIPTOR.message_types_by_name['UpgradeTask'] = _UPGRADETASK
DESCRIPTOR.message_types_by_name['UpgradeTasks'] = _UPGRADETASKS
DESCRIPTOR.message_types_by_name['AbciContext'] = _ABCICONTEXT
DESCRIPTOR.message_types_by_name['Multisig'] = _MULTISIG
DESCRIPTOR.message_types_by_name['Transaction'] = _TRANSACTION
DESCRIPTOR.message_types_by_name['TransactionInfo'] = _TRANSACTIONINFO
DESCRIPTOR.message_types_by_name['BlockInfo'] = _BLOCKINFO
DESCRIPTOR.message_types_by_name['TxStatus'] = _TXSTATUS
DESCRIPTOR.message_types_by_name['CircularQueue'] = _CIRCULARQUEUE
DESCRIPTOR.message_types_by_name['StateContext'] = _STATECONTEXT
DESCRIPTOR.message_types_by_name['StakeContext'] = _STAKECONTEXT
DESCRIPTOR.message_types_by_name['StakeSummary'] = _STAKESUMMARY
DESCRIPTOR.message_types_by_name['UnconfirmedTxs'] = _UNCONFIRMEDTXS
DESCRIPTOR.message_types_by_name['NetInfo'] = _NETINFO
DESCRIPTOR.message_types_by_name['GeoInfo'] = _GEOINFO
DESCRIPTOR.message_types_by_name['PeerInfo'] = _PEERINFO
DESCRIPTOR.message_types_by_name['ValidatorsInfo'] = _VALIDATORSINFO
DESCRIPTOR.message_types_by_name['ValidatorInfo'] = _VALIDATORINFO
DESCRIPTOR.message_types_by_name['GenesisInfo'] = _GENESISINFO
DESCRIPTOR.message_types_by_name['ForgeStatistics'] = _FORGESTATISTICS
DESCRIPTOR.message_types_by_name['TxStatistics'] = _TXSTATISTICS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BigUint = _reflection.GeneratedProtocolMessageType(
    'BigUint', (_message.Message,), dict(
        DESCRIPTOR=_BIGUINT,
        __module__='type_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.BigUint)
    ),
)
_sym_db.RegisterMessage(BigUint)

BigSint = _reflection.GeneratedProtocolMessageType(
    'BigSint', (_message.Message,), dict(
        DESCRIPTOR=_BIGSINT,
        __module__='type_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.BigSint)
    ),
)
_sym_db.RegisterMessage(BigSint)

WalletType = _reflection.GeneratedProtocolMessageType(
    'WalletType', (_message.Message,), dict(
        DESCRIPTOR=_WALLETTYPE,
        __module__='type_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.WalletType)
    ),
)
_sym_db.RegisterMessage(WalletType)

WalletInfo = _reflection.GeneratedProtocolMessageType(
    'WalletInfo', (_message.Message,), dict(
        DESCRIPTOR=_WALLETINFO,
        __module__='type_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.WalletInfo)
    ),
)
_sym_db.RegisterMessage(WalletInfo)

ChainInfo = _reflection.GeneratedProtocolMessageType(
    'ChainInfo', (_message.Message,), dict(

        ForgeAppsVersionEntry=_reflection.GeneratedProtocolMessageType(
            'ForgeAppsVersionEntry', (_message.Message,), dict(
                DESCRIPTOR=_CHAININFO_FORGEAPPSVERSIONENTRY,
                __module__='type_pb2',
                # @@protoc_insertion_point(class_scope:forge_abi.ChainInfo.ForgeAppsVersionEntry)
            ),
        ),
        DESCRIPTOR=_CHAININFO,
        __module__='type_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ChainInfo)
    ),
)
_sym_db.RegisterMessage(ChainInfo)
_sym_db.RegisterMessage(ChainInfo.ForgeAppsVersionEntry)

NodeInfo = _reflection.GeneratedProtocolMessageType(
    'NodeInfo', (_message.Message,), dict(

        ForgeAppsVersionEntry=_reflection.GeneratedProtocolMessageType(
            'ForgeAppsVersionEntry', (_message.Message,), dict(
                DESCRIPTOR=_NODEINFO_FORGEAPPSVERSIONENTRY,
                __module__='type_pb2',
                # @@protoc_insertion_point(class_scope:forge_abi.NodeInfo.ForgeAppsVersionEntry)
            ),
        ),
        DESCRIPTOR=_NODEINFO,
        __module__='type_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.NodeInfo)
    ),
)
_sym_db.RegisterMessage(NodeInfo)
_sym_db.RegisterMessage(NodeInfo.ForgeAppsVersionEntry)

Validator = _reflection.GeneratedProtocolMessageType(
    'Validator', (_message.Message,), dict(
        DESCRIPTOR=_VALIDATOR,
        __module__='type_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.Validator)
    ),
)
_sym_db.RegisterMessage(Validator)

ConsensusParams = _reflection.GeneratedProtocolMessageType(
    'ConsensusParams', (_message.Message,), dict(
        DESCRIPTOR=_CONSENSUSPARAMS,
        __module__='type_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ConsensusParams)
    ),
)
_sym_db.RegisterMessage(ConsensusParams)

UpgradeTask = _reflection.GeneratedProtocolMessageType(
    'UpgradeTask', (_message.Message,), dict(
        DESCRIPTOR=_UPGRADETASK,
        __module__='type_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.UpgradeTask)
    ),
)
_sym_db.RegisterMessage(UpgradeTask)

UpgradeTasks = _reflection.GeneratedProtocolMessageType(
    'UpgradeTasks', (_message.Message,), dict(
        DESCRIPTOR=_UPGRADETASKS,
        __module__='type_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.UpgradeTasks)
    ),
)
_sym_db.RegisterMessage(UpgradeTasks)

AbciContext = _reflection.GeneratedProtocolMessageType(
    'AbciContext', (_message.Message,), dict(
        DESCRIPTOR=_ABCICONTEXT,
        __module__='type_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.AbciContext)
    ),
)
_sym_db.RegisterMessage(AbciContext)

Multisig = _reflection.GeneratedProtocolMessageType(
    'Multisig', (_message.Message,), dict(
        DESCRIPTOR=_MULTISIG,
        __module__='type_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.Multisig)
    ),
)
_sym_db.RegisterMessage(Multisig)

Transaction = _reflection.GeneratedProtocolMessageType(
    'Transaction', (_message.Message,), dict(
        DESCRIPTOR=_TRANSACTION,
        __module__='type_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.Transaction)
    ),
)
_sym_db.RegisterMessage(Transaction)

TransactionInfo = _reflection.GeneratedProtocolMessageType(
    'TransactionInfo', (_message.Message,), dict(
        DESCRIPTOR=_TRANSACTIONINFO,
        __module__='type_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.TransactionInfo)
    ),
)
_sym_db.RegisterMessage(TransactionInfo)

BlockInfo = _reflection.GeneratedProtocolMessageType(
    'BlockInfo', (_message.Message,), dict(
        DESCRIPTOR=_BLOCKINFO,
        __module__='type_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.BlockInfo)
    ),
)
_sym_db.RegisterMessage(BlockInfo)

TxStatus = _reflection.GeneratedProtocolMessageType(
    'TxStatus', (_message.Message,), dict(
        DESCRIPTOR=_TXSTATUS,
        __module__='type_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.TxStatus)
    ),
)
_sym_db.RegisterMessage(TxStatus)

CircularQueue = _reflection.GeneratedProtocolMessageType(
    'CircularQueue', (_message.Message,), dict(
        DESCRIPTOR=_CIRCULARQUEUE,
        __module__='type_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.CircularQueue)
    ),
)
_sym_db.RegisterMessage(CircularQueue)

StateContext = _reflection.GeneratedProtocolMessageType(
    'StateContext', (_message.Message,), dict(
        DESCRIPTOR=_STATECONTEXT,
        __module__='type_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.StateContext)
    ),
)
_sym_db.RegisterMessage(StateContext)

StakeContext = _reflection.GeneratedProtocolMessageType(
    'StakeContext', (_message.Message,), dict(
        DESCRIPTOR=_STAKECONTEXT,
        __module__='type_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.StakeContext)
    ),
)
_sym_db.RegisterMessage(StakeContext)

StakeSummary = _reflection.GeneratedProtocolMessageType(
    'StakeSummary', (_message.Message,), dict(
        DESCRIPTOR=_STAKESUMMARY,
        __module__='type_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.StakeSummary)
    ),
)
_sym_db.RegisterMessage(StakeSummary)

UnconfirmedTxs = _reflection.GeneratedProtocolMessageType(
    'UnconfirmedTxs', (_message.Message,), dict(
        DESCRIPTOR=_UNCONFIRMEDTXS,
        __module__='type_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.UnconfirmedTxs)
    ),
)
_sym_db.RegisterMessage(UnconfirmedTxs)

NetInfo = _reflection.GeneratedProtocolMessageType(
    'NetInfo', (_message.Message,), dict(
        DESCRIPTOR=_NETINFO,
        __module__='type_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.NetInfo)
    ),
)
_sym_db.RegisterMessage(NetInfo)

GeoInfo = _reflection.GeneratedProtocolMessageType(
    'GeoInfo', (_message.Message,), dict(
        DESCRIPTOR=_GEOINFO,
        __module__='type_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.GeoInfo)
    ),
)
_sym_db.RegisterMessage(GeoInfo)

PeerInfo = _reflection.GeneratedProtocolMessageType(
    'PeerInfo', (_message.Message,), dict(
        DESCRIPTOR=_PEERINFO,
        __module__='type_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.PeerInfo)
    ),
)
_sym_db.RegisterMessage(PeerInfo)

ValidatorsInfo = _reflection.GeneratedProtocolMessageType(
    'ValidatorsInfo', (_message.Message,), dict(
        DESCRIPTOR=_VALIDATORSINFO,
        __module__='type_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ValidatorsInfo)
    ),
)
_sym_db.RegisterMessage(ValidatorsInfo)

ValidatorInfo = _reflection.GeneratedProtocolMessageType(
    'ValidatorInfo', (_message.Message,), dict(
        DESCRIPTOR=_VALIDATORINFO,
        __module__='type_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ValidatorInfo)
    ),
)
_sym_db.RegisterMessage(ValidatorInfo)

GenesisInfo = _reflection.GeneratedProtocolMessageType(
    'GenesisInfo', (_message.Message,), dict(
        DESCRIPTOR=_GENESISINFO,
        __module__='type_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.GenesisInfo)
    ),
)
_sym_db.RegisterMessage(GenesisInfo)

ForgeStatistics = _reflection.GeneratedProtocolMessageType(
    'ForgeStatistics', (_message.Message,), dict(
        DESCRIPTOR=_FORGESTATISTICS,
        __module__='type_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ForgeStatistics)
    ),
)
_sym_db.RegisterMessage(ForgeStatistics)

TxStatistics = _reflection.GeneratedProtocolMessageType(
    'TxStatistics', (_message.Message,), dict(
        DESCRIPTOR=_TXSTATISTICS,
        __module__='type_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.TxStatistics)
    ),
)
_sym_db.RegisterMessage(TxStatistics)


_CHAININFO_FORGEAPPSVERSIONENTRY._options = None
_NODEINFO_FORGEAPPSVERSIONENTRY._options = None
# @@protoc_insertion_point(module_scope)
